@@ -2,8 +2,7 @@ package Grizzly::Data::StockInfo;
 
 # ABSTRACT: Gets and returns stock quote
 
-use strict;
-use warnings;
+use v5.36;
 use parent qw(Exporter);
 
 use Finance::Quote;
@@ -34,7 +33,7 @@ Grizzly::Data::StockInfo - Gets and returns stock quote
 
 =head1 VERSION
 
-version 0.110
+version 0.111
 
 =head1 AUTHOR
 
