@@ -2,8 +2,7 @@ package Grizzly::Progress::Bar;
 
 # ABSTRACT: Runs a progress bar when called
 
-use strict;
-use warnings;
+use v5.36;
 use parent qw(Exporter);
 
 use Term::Clear ();
@@ -53,7 +52,7 @@ Grizzly::Progress::Bar - Runs a progress bar when called
 
 =head1 VERSION
 
-version 0.110
+version 0.111
 
 =head1 DESCRIPTION
 
